@@ -1,6 +1,6 @@
 package Catmandu::Fix::xml_write;
 #ABSTRACT: parse XML
-our $VERSION = '0.06'; #VERSION
+our $VERSION = '0.07'; #VERSION
 
 use Catmandu::Sane;
 use Moo;
@@ -12,18 +12,17 @@ with 'Catmandu::Fix::Base';
 has field      => (is => 'ro', required => 1);
 has attributes => (is => 'ro'); 
 has pretty     => (is => 'ro');
-# has encoding   => (is => 'ro');
-# has version    => (is => 'ro');
-# has standalone => (is => 'ro');
-# has xmlDecl    => (is => 'ro');
+has encoding   => (is => 'ro', default => sub { 'UTF-8' });
+has version    => (is => 'ro');
+has standalone => (is => 'ro');
+has xmldecl    => (is => 'ro', default => sub { 1 });
 
 around BUILDARGS => sub {
     my ($orig,$class,$field,%opts) = @_;
     $orig->($class, 
         field      => $field,
-        attributes => $opts{attributes},
-#        encoding   => $opts{encoding},
-        pretty     => $opts{pretty},
+        map { $_ => $opts{$_} } grep { defined $opts{$_} }
+        qw(attributes pretty encoding version standalone xmldecl)
     );
 };
 
@@ -33,7 +32,7 @@ has _writer => (
     builder => sub {
         XML::Struct::Writer->new(
             map { $_ => $_[0]->$_ } grep { defined $_[0]->$_ }
-            qw(attributes pretty)
+            qw(attributes pretty encoding version standalone xmldecl)
         );
     }
 );
@@ -51,8 +50,10 @@ sub emit {
         my $var = $_[0];     
         $fixer->emit_get_key($var,$key,sub{
             my $var = $_[0];
-            return "${var} = ${writer}->write($var) if ref(${var}) !~ 'XML::LibXML::Document=';" .
-                   "${var} = ${var}->serialize(${pretty});";
+            return "${var} = (ref(${var}) =~ 'XML::LibXML::Document=')" .
+                   "? ${var}->serialize(${pretty}) : do {".
+                       "my \$s=''; ${writer}->to(\\\$s); ${writer}->write(${var}); \$s" .
+                   "}";
         });
     });
 }
@@ -72,7 +73,7 @@ Catmandu::Fix::xml_write - parse XML
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -84,9 +85,9 @@ version 0.06
 
 This L<Catmandu::Fix> serializes XML documents (given in MicroXML form
 as used by L<XML::Struct> or as instance of L<XML::LibXML::Document>).
-In short, this is a wrapper around L<XML::Struct::Reader>.
+In short, this is a wrapper around L<XML::Struct::Writer>.
 
-=head1 OPTIONS
+=head1 CONFIGURATION
 
 =over
 
@@ -98,6 +99,14 @@ Set to false to not expect attribute hashes in the XML structure.
 
 Pretty-print XML if set to C<1>.
 
+=item xmldecl
+
+=item version
+
+=item encoding
+
+=item standalone
+
 =back
 
 =head1 SEE ALSO
